<?php

/**
 * @file
 * Theming functions for taxonomy_widget_plus module.
 */

use Drupal\Core\Template\Attribute;
use Drupal\Core\Render\Element;

/**
 * Prepares variables for the taxonomy_tree template.
 */
function template_preprocess_taxonomy_tree(array &$variables) {
  $element = $variables['element'];

  foreach (Element::children($element) as $key) {
    if (!empty($element[$key])) {
      $variables['children'][] = $element[$key];
    }
  }

  $attributes = isset($element['#attributes']) ? $element['#attributes'] : [];
  if (isset($element['#id'])) {
    $attributes['id'] = $element['#id'];
  }
  $attributes['class'][] = 'taxonomy-tree';

  if (!empty($element['#required'])) {
    $attributes['class'][] = 'required';
  }

  if (array_key_exists('#use_scrollbar', $element) && $element['#use_scrollbar']) {
    $attributes['class'][] = 'taxonomy-tree--scrollable';
  }

  if (!empty($element['#attributes']['class'])) {
    $attributes['class'] = array_merge($attributes['class'], $element['#attributes']['class']);
  }

  $variables['attributes'] = new Attribute($attributes);
}

/**
 * Prepares variables for the taxonomy_tree_root template.
 */
function template_preprocess_taxonomy_tree_root(array &$variables) {
  $element = $variables['element'];

  $attributes['class'] = [
    'taxonomy-tree-root',
  ];

  $children = Element::children($element);
  foreach ($children as $child) {
    $variables['children'][] = $element[$child];
  }

  $variables['attributes'] = new Attribute($attributes);
}

/**
 * Prepares variables for the taxonomy_tree_item template.
 */
function template_preprocess_taxonomy_tree_item(array &$variables) {
  $element = $variables['element'];
  $children = Element::children($element);

  $attributes = [];
  if (is_array($children) && count($children) > 1) {
    $attributes['class'][] = 'taxonomy-tree-item';
  }

  $variables['attributes'] = new Attribute($attributes);
  foreach ($children as $child) {
    $variables['children'][] = $element[$child];
  }
}
